@@ -253,7 +253,11 @@ class AnsiblePlaybookAction(base.TripleOAction):
             'extra_env_variables', None)
         self.queue_name = self._kwargs_for_run.pop('queue_name', None)
         self.execution_id = self._kwargs_for_run.pop('execution_id', None)
-        self._work_dir = None
+        self._work_dir = self._kwargs_for_run.pop(
+            'work_dir', None)
+        self.max_message_size = self._kwargs_for_run.pop(
+            'max_message_size', 1048576)
+        self.trash_output = self._kwargs_for_run.pop('trash_output', False)
 
     @property
     def work_dir(self):
@@ -447,6 +451,9 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 # stdout we don't know the difference. To keep the return dict
                 # similar there is an empty stderr. We can use the return code
                 # to determine if there was an error.
+                if self.trash_output:
+                    stdout = []
+                    stderr = ""
                 return {"stdout": "".join(stdout), "returncode": returncode,
                         "stderr": ""}
 
