@@ -29,7 +29,7 @@ def create_disk_images():
 
 def create_parsed_upload_images():
     uploads = [
-        {'imagename': 'tripleoupstream/heat-docker-agents-centos:latest',
+        {'imagename': 'tripleopike/heat-docker-agents-centos:current-tripleo',
          'push_destination': 'localhost:8787'},
         {'imagename': 'tripleoupstream/centos-binary-nova-compute:liberty',
          'push_destination': 'localhost:8787',
