@@ -63,6 +63,14 @@ def bracket_ipv6(address):
 CLEAR_ENV = """# Clear any old environment that may conflict.
 for key in $( set | awk '{FS=\"=\"}  /^OS_/ {print $1}' ); do unset $key ; done
 """
+CLOUDPROMPT = """
+# Add OS_CLOUDNAME to PS1
+if [ -z "${CLOUDPROMPT_ENABLED:-}" ]; then
+    export PS1=${PS1:-""}
+    export PS1=\${OS_CLOUDNAME:+"(\$OS_CLOUDNAME)"}\ $PS1
+    export CLOUDPROMPT_ENABLED=1
+fi
+"""
 
 
 def create_overcloudrc(stack, no_proxy, admin_password):
@@ -93,12 +101,15 @@ def create_overcloudrc(stack, no_proxy, admin_password):
         'OS_AUTH_URL': overcloud_endpoint,
         'OS_BAREMETAL_API_VERSION': constants.DEFAULT_BAREMETAL_API_VERSION,
         'IRONIC_API_VERSION': constants.DEFAULT_BAREMETAL_API_VERSION,
+        'OS_IMAGE_API_VERSION': constants.DEFAULT_IMAGE_API_VERSION,
+        'OS_VOLUME_API_VERSION': constants.DEFAULT_VOLUME_API_VERSION,
     }
 
     overcloudrc = CLEAR_ENV
     for key, value in rc_params.items():
         line = "export %(key)s=%(value)s\n" % {'key': key, 'value': value}
         overcloudrc = overcloudrc + line
+    overcloudrc = overcloudrc + CLOUDPROMPT
 
     rc_params.update({
         'OS_AUTH_URL': overcloud_endpoint.replace('/v2.0', '') + '/v3',
@@ -111,6 +122,7 @@ def create_overcloudrc(stack, no_proxy, admin_password):
     for key, value in rc_params.items():
         line = "export %(key)s=%(value)s\n" % {'key': key, 'value': value}
         overcloudrc_v3 = overcloudrc_v3 + line
+    overcloudrc_v3 = overcloudrc_v3 + CLOUDPROMPT
 
     return {
         "overcloudrc": overcloudrc,
